"use strict";
var routing_controllers_1 = require("routing-controllers");
var socket_controllers_1 = require("socket-controllers");
var SocketControllersExports_1 = require("./SocketControllersExports");
/**
 * socket-controllers module integration with microframework.
 */
var SocketControllersModule = (function () {
    function SocketControllersModule() {
        // -------------------------------------------------------------------------
        // Accessors
        // -------------------------------------------------------------------------
        this.ignoreMissingDependencies = true;
    }
    SocketControllersModule.prototype.getName = function () {
        return "SocketControllersModule";
    };
    SocketControllersModule.prototype.getDependentModules = function () {
        return ["ExpressModule"];
    };
    SocketControllersModule.prototype.getConfigurationName = function () {
        return "socket-controllers";
    };
    SocketControllersModule.prototype.isConfigurationRequired = function () {
        return true;
    };
    SocketControllersModule.prototype.init = function (options, configuration, dependentModules, framework) {
        this.options = options;
        this.configuration = configuration;
        this.framework = framework;
    };
    SocketControllersModule.prototype.onBootstrap = function () {
        var configuration = Object.assign({}, this.configuration);
        configuration.controllerDirs = this.getSourcePaths(configuration.controllerDirs);
        routing_controllers_1.useContainer(this.options.container);
        var io = socket_controllers_1.createSocketServer(this.configuration.port, this.configuration);
        var socketControllersExports = this.options.container.get(SocketControllersExports_1.SocketControllersExports);
        socketControllersExports.websocketsIo = io;
        return Promise.resolve();
    };
    SocketControllersModule.prototype.afterBootstrap = function () {
        return Promise.resolve();
    };
    SocketControllersModule.prototype.onShutdown = function () {
        return Promise.resolve();
    };
    // -------------------------------------------------------------------------
    // Private Methods
    // -------------------------------------------------------------------------
    SocketControllersModule.prototype.getSourcePaths = function (dirs) {
        var _this = this;
        if (!dirs || !dirs.length)
            return [];
        return dirs.map(function (dir) { return _this.options.frameworkSettings.srcDirectory + "/" + dir; });
    };
    return SocketControllersModule;
}());
exports.SocketControllersModule = SocketControllersModule;
//# sourceMappingURL=SocketControllersModule.js.map